Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(646)

Unified Diff: public/web/WebNavigatorContentUtilsClient.h

Issue 18179009: Introduce unregisterProtocolHandler() and isProtocolHandlerRegistered() webview API (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Rebased Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/web/ChromeClientImpl.cpp ('k') | public/web/WebViewClient.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: public/web/WebNavigatorContentUtilsClient.h
diff --git a/public/web/WebPageVisibilityState.h b/public/web/WebNavigatorContentUtilsClient.h
similarity index 82%
copy from public/web/WebPageVisibilityState.h
copy to public/web/WebNavigatorContentUtilsClient.h
index fe02afd42d3c962943ab58e9346e3727b9b218a7..17350bb46d511e967e5b303c1cc2df75a49cd4c6 100644
--- a/public/web/WebPageVisibilityState.h
+++ b/public/web/WebNavigatorContentUtilsClient.h
@@ -1,5 +1,5 @@
/*
- * Copyright (C) 2011 Google Inc. All rights reserved.
+ * Copyright (C) 2014, Samsung Electronics. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are
@@ -28,17 +28,17 @@
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-#ifndef WebPageVisibilityState_h
-#define WebPageVisibilityState_h
+#ifndef WebNavigatorContentUtilsClient_h
+#define WebNavigatorContentUtilsClient_h
namespace blink {
// The following enum should be consistent with the PageVisibilityState enum
// defined in WebCore.
-enum WebPageVisibilityState {
- WebPageVisibilityStateVisible,
- WebPageVisibilityStateHidden,
- WebPageVisibilityStatePrerender,
+enum WebCustomHandlersState {
+ WebCustomHandlersNew,
+ WebCustomHandlersRegistered,
+ WebCustomHandlersDeclined
};
} // namespace blink
« no previous file with comments | « Source/web/ChromeClientImpl.cpp ('k') | public/web/WebViewClient.h » ('j') | no next file with comments »
@@ -28,17 +28,17 @@
namespace blink {
-// The following enum should be consistent with the PageVisibilityState enum
+// The following enum should be consistent with the CustomHandlersState enum
// defined in WebCore.

Powered by Google App Engine
This is Rietveld 408576698